Struct Cifr
#[repr(transparent)]pub struct Cifr(pub u32);Expand description
CIFR register.
Tuple Fields
0: u32Implementations
impl Cifr
impl Cifr
pub const fn lsirdyif(&self) -> bool
pub const fn lsirdyif(&self) -> bool
LSI Ready Interrupt flag Set by hardware when LSI clock becomes stable.
pub const fn set_lsirdyif(&mut self, val: bool)
pub const fn set_lsirdyif(&mut self, val: bool)
LSI Ready Interrupt flag Set by hardware when LSI clock becomes stable.
pub const fn lserdyif(&self) -> bool
pub const fn lserdyif(&self) -> bool
LSE Ready Interrupt Flag. Set by hardware when LSE clock becomes stable.
pub const fn set_lserdyif(&mut self, val: bool)
pub const fn set_lserdyif(&mut self, val: bool)
LSE Ready Interrupt Flag. Set by hardware when LSE clock becomes stable.
pub const fn hsirdyif(&self) -> bool
pub const fn hsirdyif(&self) -> bool
HSI Ready Interrupt Flag. Set by hardware when HSI becomes stable.
pub const fn set_hsirdyif(&mut self, val: bool)
pub const fn set_hsirdyif(&mut self, val: bool)
HSI Ready Interrupt Flag. Set by hardware when HSI becomes stable.
pub const fn hserdyif(&self) -> bool
pub const fn hserdyif(&self) -> bool
HSE Ready Interrupt Flag. Set by hardware when HSE becomes stable.
pub const fn set_hserdyif(&mut self, val: bool)
pub const fn set_hserdyif(&mut self, val: bool)
HSE Ready Interrupt Flag. Set by hardware when HSE becomes stable.
pub const fn hsipllrdyif(&self) -> bool
pub const fn hsipllrdyif(&self) -> bool
HSI PLL Ready Interrupt Flag. Set by hardware when HSI PLL 64MHz becomes stable.
pub const fn set_hsipllrdyif(&mut self, val: bool)
pub const fn set_hsipllrdyif(&mut self, val: bool)
HSI PLL Ready Interrupt Flag. Set by hardware when HSI PLL 64MHz becomes stable.
pub const fn hsipllunlockdetif(&self) -> bool
pub const fn hsipllunlockdetif(&self) -> bool
HSIPLLUNLOCKDETIF: HSI PLL unlock detection Interrupt Flag.
pub const fn set_hsipllunlockdetif(&mut self, val: bool)
pub const fn set_hsipllunlockdetif(&mut self, val: bool)
HSIPLLUNLOCKDETIF: HSI PLL unlock detection Interrupt Flag.
pub const fn rtcrstif(&self) -> bool
pub const fn rtcrstif(&self) -> bool
RTC reset end Interrupt Flag. Raised when reset is released on 32kHz clock.
pub const fn set_rtcrstif(&mut self, val: bool)
pub const fn set_rtcrstif(&mut self, val: bool)
RTC reset end Interrupt Flag. Raised when reset is released on 32kHz clock.
pub const fn wdgrstif(&self) -> bool
pub const fn wdgrstif(&self) -> bool
WDG reset end Interrupt Flag. Raised when reset is released on 32kHz clock.
pub const fn set_wdgrstif(&mut self, val: bool)
pub const fn set_wdgrstif(&mut self, val: bool)
WDG reset end Interrupt Flag. Raised when reset is released on 32kHz clock.
pub const fn set_lpurstf(&mut self, val: bool)
pub const fn set_lpurstf(&mut self, val: bool)
LPUART reset release flag.